summaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorfisharebest <fisharebest@gmail.com>2011-01-01 10:46:42 +0000
committerfisharebest <fisharebest@gmail.com>2011-01-01 10:46:42 +0000
commit3f00e12930f917fcd52629041b942db9bec5f701 (patch)
tree7f29e3ba19d410454032317a7df98de212cdc550 /modules
parent8bc6f5e19764516c1e997578ea04b08e77d182df (diff)
downloadwebtrees-3f00e12930f917fcd52629041b942db9bec5f701.tar.gz
webtrees-3f00e12930f917fcd52629041b942db9bec5f701.tar.bz2
webtrees-3f00e12930f917fcd52629041b942db9bec5f701.zip
Refactoring class names and use autoloading.
Diffstat (limited to 'modules')
-rw-r--r--modules/GEDFact_assistant/CENS_ctrl.php5
-rw-r--r--modules/GEDFact_assistant/MEDIA_ctrl.php3
-rw-r--r--modules/GEDFact_assistant/_CENS/census_1_ctrl.php2
-rw-r--r--modules/GEDFact_assistant/_CENS/census_3_find.php2
-rw-r--r--modules/GEDFact_assistant/_CENS/census_3_search_add.php26
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_0_inverselink.php2
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_1_ctrl.php2
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_3_find.php2
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_3_search_add.php2
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_query_1a.php8
-rw-r--r--modules/GEDFact_assistant/_MEDIA/media_query_3a.php4
-rw-r--r--modules/batch_update/admin_batch_update.php2
-rw-r--r--modules/batch_update/plugins/death_y.php2
-rw-r--r--modules/charts/module.php9
-rw-r--r--modules/clippings/clippings_ctrl.php24
-rw-r--r--modules/clippings/index.php6
-rw-r--r--modules/clippings/module.php12
-rw-r--r--modules/descendancy/module.php10
-rw-r--r--modules/families/module.php2
-rw-r--r--modules/family_nav/module.php9
-rw-r--r--modules/gedcom_favorites/module.php4
-rw-r--r--modules/googlemap/googlemap.php12
-rw-r--r--modules/googlemap/pedigree_map.php7
-rw-r--r--modules/individuals/module.php2
-rw-r--r--modules/lightbox/album.php2
-rw-r--r--modules/lightbox/functions/lightbox_print_media_row.php2
-rw-r--r--modules/relatives/module.php4
-rw-r--r--modules/review_changes/module.php2
-rw-r--r--modules/stories/module.php6
-rw-r--r--modules/todo/module.php3
-rw-r--r--modules/top10_pageviews/module.php2
-rw-r--r--modules/user_favorites/module.php2
-rw-r--r--modules/yahrzeit/module.php1
33 files changed, 87 insertions, 96 deletions
diff --git a/modules/GEDFact_assistant/CENS_ctrl.php b/modules/GEDFact_assistant/CENS_ctrl.php
index 3351757a35..0712d09572 100644
--- a/modules/GEDFact_assistant/CENS_ctrl.php
+++ b/modules/GEDFact_assistant/CENS_ctrl.php
@@ -28,9 +28,8 @@
* @subpackage Census Assistant
* @version $Id$
*/
-// require_once './config.php';
-require_once 'includes/controllers/individual_ctrl.php';
-$controller = new IndividualController();
+
+$controller = new WT_Controller_Individual();
$controller->init();
global $USE_THUMBS_MAIN, $tabno;
diff --git a/modules/GEDFact_assistant/MEDIA_ctrl.php b/modules/GEDFact_assistant/MEDIA_ctrl.php
index 24a379e1b0..346afd82da 100644
--- a/modules/GEDFact_assistant/MEDIA_ctrl.php
+++ b/modules/GEDFact_assistant/MEDIA_ctrl.php
@@ -29,8 +29,7 @@
* @version $Id$
*/
-require_once WT_ROOT.'includes/controllers/individual_ctrl.php';
-$controller = new IndividualController();
+$controller = new WT_Controller_Individual();
$controller->init();
echo "<link href =\"modules/GEDFact_assistant/css/gf_styles.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />";
diff --git a/modules/GEDFact_assistant/_CENS/census_1_ctrl.php b/modules/GEDFact_assistant/_CENS/census_1_ctrl.php
index 19a87ecdd4..2f2957bc01 100644
--- a/modules/GEDFact_assistant/_CENS/census_1_ctrl.php
+++ b/modules/GEDFact_assistant/_CENS/census_1_ctrl.php
@@ -47,7 +47,7 @@ $ctry = "UK";
// === Set $married to "Not married as we only want the Birth name here" ===
$married=-1;
-$person=Person::getInstance($pid);
+$person=WT_Person::getInstance($pid);
// var_dump($person->getAllNames());
$nam = $person->getAllNames();
if (PrintReady($person->getDeathYear()) == 0) { $DeathYr = ""; } else { $DeathYr = PrintReady($person->getDeathYear()); }
diff --git a/modules/GEDFact_assistant/_CENS/census_3_find.php b/modules/GEDFact_assistant/_CENS/census_3_find.php
index a1c5f37e61..c0454945de 100644
--- a/modules/GEDFact_assistant/_CENS/census_3_find.php
+++ b/modules/GEDFact_assistant/_CENS/census_3_find.php
@@ -917,7 +917,7 @@ if ($action=="filter") {
echo i18n::translate('This media object is linked to the following:'), "<br />";
foreach ($media["LINKS"] as $indi => $type_record) {
if ($type_record!='INDI' && $type_record!='FAM' && $type_record!='SOUR' && $type_record!='OBJE') continue;
- $record=GedcomRecord::getInstance($indi);
+ $record=WT_GedcomRecord::getInstance($indi);
echo '<br /><a href="', $record->getHtmlUrl(), '">';
switch($type_record) {
case 'INDI':
diff --git a/modules/GEDFact_assistant/_CENS/census_3_search_add.php b/modules/GEDFact_assistant/_CENS/census_3_search_add.php
index ff27b01a99..82fb2e439d 100644
--- a/modules/GEDFact_assistant/_CENS/census_3_search_add.php
+++ b/modules/GEDFact_assistant/_CENS/census_3_search_add.php
@@ -140,7 +140,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["husb"])) {
//-- Parents Husbands Parents --------------------------------------
- $gparent=Person::getInstance($people["husb"]->getXref());
+ $gparent=WT_Person::getInstance($people["husb"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -264,7 +264,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["wife"])) {
//-- Parents Wifes Parent Family ---------------------------
- $gparent=Person::getInstance($people["wife"]->getXref());
+ $gparent=WT_Person::getInstance($people["wife"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -587,7 +587,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["husb"])) {
//-- Step Husbands Parent Family --------------------------------------
- $gparent=Person::getInstance($people["husb"]->getXref());
+ $gparent=WT_Person::getInstance($people["husb"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -723,7 +723,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["wife"])) {
//-- Step Wifes Parent Family --------------------------------------
- $gparent=Person::getInstance($people["wife"]->getXref());
+ $gparent=WT_Person::getInstance($people["wife"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -1030,7 +1030,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["husb"])) {
//-- Spouse Husbands Parents --------------------------------------
- $gparent=Person::getInstance($people["husb"]->getXref());
+ $gparent=WT_Person::getInstance($people["husb"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -1165,7 +1165,7 @@ if (!defined('WT_WEBTREES')) {
if (isset($people["wife"])) {
//-- Spouse Wifes Parents --------------------------------------
- $gparent=Person::getInstance($people["wife"]->getXref());
+ $gparent=WT_Person::getInstance($people["wife"]->getXref());
$fams = $gparent->getChildFamilies();
foreach ($fams as $famid=>$family) {
if (!is_null($family)) {
@@ -1489,7 +1489,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
if (!isset($OLD_PGENS)) $OLD_PGENS = $DEFAULT_PEDIGREE_GENERATIONS;
if (!isset($talloffset)) $talloffset = $PEDIGREE_LAYOUT;
- $person=Person::getInstance($pid);
+ $person=WT_Person::getInstance($pid);
if ($pid==false || empty($person)) {
$spouselinks = false;
$parentlinks = false;
@@ -1566,7 +1566,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
}
if ($husb) {
//-- Parent Husbands Parents ----------------------
- $gparent=Person::getInstance($husb->getXref());
+ $gparent=WT_Person::getInstance($husb->getXref());
$parfams = $gparent->getChildFamilies();
foreach ($parfams as $famid=>$pfamily) {
if (!is_null($pfamily)) {
@@ -1658,7 +1658,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
}
if ($wife) {
//-- Parent Wifes Parents ----------------------
- $gparent=Person::getInstance($wife->getXref());
+ $gparent=WT_Person::getInstance($wife->getXref());
$parfams = $gparent->getChildFamilies();
foreach ($parfams as $famid=>$pfamily) {
if (!is_null($pfamily)) {
@@ -1795,7 +1795,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
}
if ($husb) {
//-- Step Husbands Parents -----------------------------
- $gparent=Person::getInstance($husb->getXref());
+ $gparent=WT_Person::getInstance($husb->getXref());
$parfams = $gparent->getChildFamilies();
foreach ($parfams as $famid=>$pfamily) {
if (!is_null($pfamily)) {
@@ -1890,7 +1890,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
}
if ($wife) {
//-- Step Wifes Parents ---------------------------
- $gparent=Person::getInstance($wife->getXref());
+ $gparent=WT_Person::getInstance($wife->getXref());
$parfams = $gparent->getChildFamilies();
foreach ($parfams as $famid=>$pfamily) {
if (!is_null($pfamily)) {
@@ -2026,7 +2026,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
if ($spouse) {
//-- Spouse Parents -----------------------------
- $gparent=Person::getInstance($spouse->getXref());
+ $gparent=WT_Person::getInstance($spouse->getXref());
$spousefams = $gparent->getChildFamilies();
foreach ($spousefams as $famid=>$pfamily) {
if (!is_null($pfamily)) {
@@ -2134,7 +2134,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
$persons="Yes";
//-- Childs Parents ---------------------
- $gparent=Person::getInstance($child->getXref());
+ $gparent=WT_Person::getInstance($child->getXref());
$fams = $gparent->getChildFamilies();
$chfams = $gparent->getSpouseFamilies();
foreach ($fams as $famid=>$family) {
diff --git a/modules/GEDFact_assistant/_MEDIA/media_0_inverselink.php b/modules/GEDFact_assistant/_MEDIA/media_0_inverselink.php
index 16dcd1b92d..e352b47ab2 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_0_inverselink.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_0_inverselink.php
@@ -169,7 +169,7 @@ if ($action == "choose" && $paramok) {
if ($linktoid=="") {
// ----
} else {
- $record=Person::getInstance($linktoid);
+ $record=WT_Person::getInstance($linktoid);
echo '<b>', PrintReady($record->getFullName()), '</b>&nbsp;&nbsp;&nbsp;';
if ($TEXT_DIRECTION=="rtl") echo getRLM();
echo '(', $linktoid, ')';
diff --git a/modules/GEDFact_assistant/_MEDIA/media_1_ctrl.php b/modules/GEDFact_assistant/_MEDIA/media_1_ctrl.php
index ecf70fc218..c74015fb69 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_1_ctrl.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_1_ctrl.php
@@ -56,7 +56,7 @@ if ($pid=="") {
echo "<br /><br />";
} else {
- $person=Person::getInstance($pid);
+ $person=WT_Person::getInstance($pid);
// var_dump($person->getAllNames());
$nam = $person->getAllNames();
if (PrintReady($person->getDeathYear()) == 0) { $DeathYr = ""; } else { $DeathYr = PrintReady($person->getDeathYear()); }
diff --git a/modules/GEDFact_assistant/_MEDIA/media_3_find.php b/modules/GEDFact_assistant/_MEDIA/media_3_find.php
index d88676f656..be68ce8d14 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_3_find.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_3_find.php
@@ -612,7 +612,7 @@ if ($action=="filter") {
echo i18n::translate('This media object is linked to the following:'), "<br />";
foreach ($media["LINKS"] as $indi => $type_record) {
if ($type_record!='INDI' && $type_record!='FAM' && $type_record!='SOUR' && $type_record!='OBJE') continue;
- $record=GedcomRecord::getInstance($indi);
+ $record=WT_GedcomRecord::getInstance($indi);
echo '<br /><a href="', $record->getHtmlUrl(), '">';
switch($type_record) {
case 'INDI':
diff --git a/modules/GEDFact_assistant/_MEDIA/media_3_search_add.php b/modules/GEDFact_assistant/_MEDIA/media_3_search_add.php
index 17fb82bf43..e100d14037 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_3_search_add.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_3_search_add.php
@@ -1025,7 +1025,7 @@ function print_pedigree_person_nav2($pid, $style=1, $count=0, $personcount="1",
if (!isset($OLD_PGENS)) $OLD_PGENS = $DEFAULT_PEDIGREE_GENERATIONS;
if (!isset($talloffset)) $talloffset = $PEDIGREE_LAYOUT;
- $person=Person::getInstance($pid);
+ $person=WT_Person::getInstance($pid);
if ($pid==false || empty($person)) {
$spouselinks = false;
$parentlinks = false;
diff --git a/modules/GEDFact_assistant/_MEDIA/media_query_1a.php b/modules/GEDFact_assistant/_MEDIA/media_query_1a.php
index 00cd4004e1..35c13ad3db 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_query_1a.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_query_1a.php
@@ -58,23 +58,23 @@ if (stristr($_SERVER["SCRIPT_NAME"], basename(__FILE__))!==false) {
$values = array_values($links);
$i=1;
foreach ($keys as $link) {
- $record=GedcomRecord::getInstance($link);
+ $record=WT_GedcomRecord::getInstance($link);
echo "<tr ><td>";
echo $i;
echo "</td><td id=\"existId_", $i, "\" class=\"row2\">";
echo $link;
echo "</td><td>";
if ($record->getType()=='INDI') {
- $idrecord=Person::getInstance($link);
+ $idrecord=WT_Person::getInstance($link);
} elseif ($record->getType()=='FAM') {
- $idrecord=Family::getInstance($link);
+ $idrecord=WT_Family::getInstance($link);
if ($idrecord->getHusbId()) {
$head=$idrecord->getHusbId();
} else {
$head=$idrecord->getWifeId();
}
} elseif ($record->getType()=='SOUR') {
- $idrecord=Source::getInstance($link);
+ $idrecord=WT_Source::getInstance($link);
} else {
}
diff --git a/modules/GEDFact_assistant/_MEDIA/media_query_3a.php b/modules/GEDFact_assistant/_MEDIA/media_query_3a.php
index c22c3006e8..bc12c8ebc5 100644
--- a/modules/GEDFact_assistant/_MEDIA/media_query_3a.php
+++ b/modules/GEDFact_assistant/_MEDIA/media_query_3a.php
@@ -36,11 +36,11 @@ $iid2 = safe_GET('iid');
print_simple_header(i18n::translate('Link media'));
-$record=GedcomRecord::getInstance($iid2);
+$record=WT_GedcomRecord::getInstance($iid2);
$headjs="";
if ($record) {
if ($record->getType()=='FAM') {
- $idrecord=Family::getInstance($iid2);
+ $idrecord=WT_Family::getInstance($iid2);
if ($idrecord->getHusbId()) {
$headjs=$idrecord->getHusbId();
} else {
diff --git a/modules/batch_update/admin_batch_update.php b/modules/batch_update/admin_batch_update.php
index 347951d7d2..d32c8b03e3 100644
--- a/modules/batch_update/admin_batch_update.php
+++ b/modules/batch_update/admin_batch_update.php
@@ -101,7 +101,7 @@ class batch_update {
} else {
if ($this->curr_xref) {
// Create an object, so we can get the latest version of the name.
- $object=GedcomRecord::getInstance($this->curr_xref);
+ $object=WT_GedcomRecord::getInstance($this->curr_xref);
$object->setGedcomRecord($this->record);
$html.=
diff --git a/modules/batch_update/plugins/death_y.php b/modules/batch_update/plugins/death_y.php
index eb021ab635..ccdf9841cd 100644
--- a/modules/batch_update/plugins/death_y.php
+++ b/modules/batch_update/plugins/death_y.php
@@ -42,7 +42,7 @@ class death_y_bu_plugin extends base_plugin {
}
static function doesRecordNeedUpdate($xref, $gedrec) {
- return !preg_match('/^1\s+'.WT_EVENTS_DEAT.'\b/m', $gedrec) && Person::getInstance($xref)->isDead();
+ return !preg_match('/^1\s+'.WT_EVENTS_DEAT.'\b/m', $gedrec) && WT_Person::getInstance($xref)->isDead();
}
static function updateRecord($xref, $gedrec) {
diff --git a/modules/charts/module.php b/modules/charts/module.php
index 6099c1e171..7a59dd9022 100644
--- a/modules/charts/module.php
+++ b/modules/charts/module.php
@@ -31,7 +31,6 @@ if (!defined('WT_WEBTREES')) {
}
require_once WT_ROOT.'includes/classes/class_module.php';
-require_once WT_ROOT.'includes/controllers/hourglass_ctrl.php';
require_once WT_ROOT.'includes/classes/class_treenav.php';
class charts_WT_Module extends WT_Module implements WT_Module_Block {
@@ -74,7 +73,7 @@ class charts_WT_Module extends WT_Module implements WT_Module_Block {
$PEDIGREE_FULL_DETAILS = $show_full;
if ($type!='treenav') {
- $controller = new HourglassController();
+ $controller = new WT_Controller_Hourglass();
$controller->init($pid,0,3);
$controller->setupJavascript();
} else {
@@ -82,11 +81,11 @@ class charts_WT_Module extends WT_Module implements WT_Module_Block {
$nav->generations = 2;
}
- $person = Person::getInstance($pid);
+ $person = WT_Person::getInstance($pid);
if ($person==null) {
$pid = $PEDIGREE_ROOT_ID;
set_block_setting($block_id, 'pid', $pid);
- $person = Person::getInstance($pid);
+ $person = WT_Person::getInstance($pid);
}
$id=$this->getName().$block_id;
@@ -225,7 +224,7 @@ class charts_WT_Module extends WT_Module implements WT_Module_Block {
<input type="text" name="pid" id="pid" value="<?php echo $pid; ?>" size="5" />
<?php
print_findindi_link('pid','');
- $root=Person::getInstance($pid);
+ $root=WT_Person::getInstance($pid);
if ($root) {
echo ' <span class="list_item">', $root->getFullName(), $root->format_first_major_fact(WT_EVENTS_BIRT, 1), '</span>';
}
diff --git a/modules/clippings/index.php b/modules/clippings/index.php
index a726cb92e5..43f5be0948 100644
--- a/modules/clippings/index.php
+++ b/modules/clippings/index.php
@@ -34,7 +34,7 @@ require_once WT_ROOT.'modules/clippings/clippings_ctrl.php';
global $ENABLE_AUTOCOMPLETE, $cart, $MAX_PEDIGREE_GENERATIONS, $TEXT_DIRECTION, $GEDCOM, $WT_IMAGES;
-$controller = new ClippingsController();
+$controller = new WT_Controller_Clippings();
$controller->init();
// -- print html header information
@@ -51,7 +51,7 @@ if (count($cart)==0) { ?>
<?php }
if ($controller->action=='add') {
- $person = GedcomRecord::getInstance($controller->id);
+ $person = WT_GedcomRecord::getInstance($controller->id);
echo "<b>".$person->getFullName()."</b>";
if ($controller->type=='fam') { ?>
<form action="module.php" method="get">
@@ -300,7 +300,7 @@ if ($ct==0) {
<td class="list_value ltr"><?php echo $clipping['id']; ?></td>
<td class="list_value">
<?php
- $record=GedcomRecord::getInstance($clipping['id']);
+ $record=WT_GedcomRecord::getInstance($clipping['id']);
if ($record) echo '<a href="', $record->getHtmlUrl(), '">', PrintReady($record->getListName()), '</a>';
?>
</td>
diff --git a/modules/clippings/module.php b/modules/clippings/module.php
index bd301abd0d..0b1cb11e0e 100644
--- a/modules/clippings/module.php
+++ b/modules/clippings/module.php
@@ -142,13 +142,13 @@ class clippings_WT_Module extends WT_Module implements WT_Module_Menu, WT_Module
$out .= $this->getCartList();
$root = null;
if ($this->controller->pid && !id_in_cart($this->controller->pid)) {
- $root = GedcomRecord::getInstance($this->controller->pid);
+ $root = WT_GedcomRecord::getInstance($this->controller->pid);
if ($root && $root->canDisplayDetails())
$out .= '<a href="sidebar.php?sb_action=clippings&amp;add='.$root->getXref().'" class="add_cart">
<img src="'.$WT_IMAGES['clippings'].'" width="20" /> '.i18n::translate('Add %s to cart', $root->getListName()).'</a>';
}
else if ($this->controller->famid && !id_in_cart($this->controller->pid)) {
- $fam = Family::getInstance($this->controller->famid);
+ $fam = WT_Family::getInstance($this->controller->famid);
if ($fam && $fam->canDisplayDetails()) {
$out .= '<a href="sidebar.php?sb_action=clippings&amp;add='.$fam->getXref().'" class="add_cart"> '.i18n::translate('Add %s to cart', $fam->getFullName()).'</a><br />';
}
@@ -161,7 +161,7 @@ class clippings_WT_Module extends WT_Module implements WT_Module_Menu, WT_Module
// Impelement WT_Module_Sidebar
public function getSidebarAjaxContent() {
global $cart;
- $controller = new ClippingsController();
+ $controller = new WT_Controller_Clippings();
$this->controller = $controller;
$add = safe_GET_xref('add','');
$add1 = safe_GET_xref('add1','');
@@ -171,7 +171,7 @@ class clippings_WT_Module extends WT_Module implements WT_Module_Menu, WT_Module
$controller->level2 = safe_GET('level2');
$controller->level3 = safe_GET('level3');
if (!empty($add)) {
- $record = GedcomRecord::getInstance($add);
+ $record = WT_GedcomRecord::getInstance($add);
if ($record) {
$controller->id=$record->getXref();
$controller->type=$record->getType();
@@ -185,7 +185,7 @@ class clippings_WT_Module extends WT_Module implements WT_Module_Menu, WT_Module
}
}
else if (!empty($add1)) {
- $record = GedcomRecord::getInstance($add1);
+ $record = WT_GedcomRecord::getInstance($add1);
if ($record) {
$controller->id=$record->getXref();
$controller->type=strtolower($record->getType());
@@ -309,7 +309,7 @@ class clippings_WT_Module extends WT_Module implements WT_Module_Menu, WT_Module
if (!empty($icon)) {
$out .= '<img src="'.$WT_IMAGES[$icon].'" border="0" alt="'.$tag.'" title="'.$tag.'" width="20" />';
}
- $record=GedcomRecord::getInstance($clipping['id']);
+ $record=WT_GedcomRecord::getInstance($clipping['id']);
if ($record) {
$out .= '<a href="'.$record->getHtmlUrl().'">';
if ($record->getType()=="INDI") $out .=$record->getSexImage();
diff --git a/modules/descendancy/module.php b/modules/descendancy/module.php
index 311930073f..518024006b 100644
--- a/modules/descendancy/module.php
+++ b/modules/descendancy/module.php
@@ -123,10 +123,10 @@ class descendancy_WT_Module extends WT_Module implements WT_Module_Sidebar {
if ($this->controller) {
$root = null;
if ($this->controller->pid) {
- $root = Person::getInstance($this->controller->pid);
+ $root = WT_Person::getInstance($this->controller->pid);
}
else if ($this->controller->famid) {
- $fam = Family::getInstance($this->controller->famid);
+ $fam = WT_Family::getInstance($this->controller->famid);
if ($fam) $root = $fam->getHusband();
if (!$root) $root = $fam->getWife();
}
@@ -203,7 +203,7 @@ class descendancy_WT_Module extends WT_Module implements WT_Module_Sidebar {
$out = '<ul>';
$private_count = 0;
foreach ($rows as $row) {
- $person=Person::getInstance($row);
+ $person=PWT_erson::getInstance($row);
if ($person->canDisplayName()) {
$out .= $this->getPersonLi($person);
}
@@ -216,7 +216,7 @@ class descendancy_WT_Module extends WT_Module implements WT_Module_Sidebar {
public function loadSpouses($pid, $generations=0) {
$out = '<ul>';
- $person = Person::getInstance($pid);
+ $person = WT_Person::getInstance($pid);
if ($person->canDisplayDetails()) {
$families = $person->getSpouseFamilies();
foreach ($families as $family) {
@@ -232,7 +232,7 @@ class descendancy_WT_Module extends WT_Module implements WT_Module_Sidebar {
public function loadChildren($famid, $generations=0) {
$out = '<ul>';
- $family = Family::getInstance($famid);
+ $family = WT_Family::getInstance($famid);
if ($family->canDisplayDetails()) {
$children = $family->getChildren();
if (count($children)>0) {
diff --git a/modules/families/module.php b/modules/families/module.php
index d01b2137c9..9df886f0ca 100644
--- a/modules/families/module.php
+++ b/modules/families/module.php
@@ -242,7 +242,7 @@ class families_WT_Module extends WT_Module implements WT_Module_Sidebar {
$out = '<ul>';
$private_count = 0;
foreach ($rows as $row) {
- $family=Family::getInstance($row);
+ $family=WT_Family::getInstance($row);
if ($family->canDisplayName()) {
$out .= '<li><a href="'.$family->getHtmlUrl().'">'.$family->getFullName().' ';
if ($family->canDisplayDetails()) {
diff --git a/modules/family_nav/module.php b/modules/family_nav/module.php
index 16f3bd897b..1eceba1ead 100644
--- a/modules/family_nav/module.php
+++ b/modules/family_nav/module.php
@@ -34,7 +34,6 @@ if (!defined('WT_WEBTREES')) {
require_once WT_ROOT.'includes/classes/class_module.php';
require_once WT_ROOT.'includes/functions/functions_charts.php';
-require_once WT_ROOT.'includes/controllers/individual_ctrl.php';
class family_nav_WT_Module extends WT_Module implements WT_Module_Sidebar {
// Extend WT_Module
@@ -66,15 +65,15 @@ class family_nav_WT_Module extends WT_Module implements WT_Module_Sidebar {
if ($this->controller) {
$root = null;
if ($this->controller->pid) {
- $root = Person::getInstance($this->controller->pid);
+ $root = WT_Person::getInstance($this->controller->pid);
}
else if ($this->controller->famid) {
- $fam = Family::getInstance($this->controller->famid);
+ $fam = WT_Family::getInstance($this->controller->famid);
if ($fam) $root = $fam->getHusband();
if (!$root) $root = $fam->getWife();
}
if ($root!=null) {
- $this->controller = new IndividualController();
+ $this->controller = new WT_Controller_Individual();
$this->controller->indi=$root;
$this->controller->pid=$root->getXref();
$this->setController($this->controller);
@@ -543,7 +542,7 @@ class family_nav_WT_Module extends WT_Module implements WT_Module_Sidebar {
if (!isset($OLD_PGENS)) $OLD_PGENS = $DEFAULT_PEDIGREE_GENERATIONS;
if (!isset($talloffset)) $talloffset = $PEDIGREE_LAYOUT;
- $person=Person::getInstance($pid);
+ $person=WT_Person::getInstance($pid);
if ($pid==false || empty($person)) {
$spouselinks = false;
$parentlinks = false;
diff --git a/modules/gedcom_favorites/module.php b/modules/gedcom_favorites/module.php
index dcf226da8a..57f722ebd4 100644
--- a/modules/gedcom_favorites/module.php
+++ b/modules/gedcom_favorites/module.php
@@ -194,7 +194,7 @@ class gedcom_favorites_WT_Module extends WT_Module implements WT_Module_Block {
$content .= "<br />".PrintReady($favorite["note"]);
$content .= "</div>";
} else {
- $record=GedcomRecord::getInstance($favorite['gid']);
+ $record=WT_GedcomRecord::getInstance($favorite['gid']);
if ($record && $record->canDisplayDetails()) {
if ($favorite["type"]=="INDI") {
$indirec = find_person_record($favorite["gid"], WT_GED_ID);
@@ -210,7 +210,7 @@ class gedcom_favorites_WT_Module extends WT_Module implements WT_Module_Block {
$content .= PrintReady($favorite["note"]);
$content .= "</div>";
} else {
- $record=GedcomRecord::getInstance($favorite['gid']);
+ $record=WT_GedcomRecord::getInstance($favorite['gid']);
$content .= "<div id=\"box".$favorite["gid"].".0\" class=\"person_box\">";
if ($ctype=="user" || WT_USER_GEDCOM_ADMIN) $content .= $removeFavourite;
if ($record) {
diff --git a/modules/googlemap/googlemap.php b/modules/googlemap/googlemap.php
index 072012052d..8e7148ade7 100644
--- a/modules/googlemap/googlemap.php
+++ b/modules/googlemap/googlemap.php
@@ -332,7 +332,7 @@ function tool_tip_text($marker) {
if (!empty($marker['info']))
$tool_tip.=": {$marker['info']}";
if (!empty($marker['name'])) {
- $person=Person::getInstance($marker['name']);
+ $person=WT_Person::getInstance($marker['name']);
if ($person && $person->canDisplayName()) {
$tool_tip.=": ".PrintReady($person->getFullName());
}
@@ -535,7 +535,7 @@ function build_indiv_map($indifacts, $famids) {
if ($famrec) {
$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch, PREG_SET_ORDER);
for ($j=0; $j<$num; $j++) {
- $person=Person::getInstance($smatch[$j][1]);
+ $person=WT_Person::getInstance($smatch[$j][1]);
if ($person->canDisplayDetails()) {
$srec = find_person_record($smatch[$j][1], WT_GED_ID);
$birthrec = '';
@@ -682,7 +682,7 @@ function build_indiv_map($indifacts, $famids) {
if (!empty($markers[$j]['info']))
echo ': ', addslashes($markers[$j]['info']);
if (!empty($markers[$j]["name"])) {
- $person=Person::getInstance($markers[$j]['name']);
+ $person=WT_Person::getInstance($markers[$j]['name']);
if ($person) {
echo ': <a href=\"', $person->getRawUrl(), '\">', $person->canDisplayName() ? PrintReady(addcslashes($person->getFullName(), '"')) : i18n::translate('Private'), '</a>';
}
@@ -742,7 +742,7 @@ function build_indiv_map($indifacts, $famids) {
if (!empty($markers[$j]['info']))
echo ': ', addslashes($markers[$j]['info']);
if (!empty($markers[$j]["name"])) {
- $person=Person::getInstance($markers[$j]['name']);
+ $person=WT_Person::getInstance($markers[$j]['name']);
if ($person) {
echo ': <a href=\"', $person->getRawUrl(), '\">', $person->canDisplayName() ? PrintReady(addcslashes($person->getFullName(), '"')) : i18n::translate('Private'), '</a>';
}
@@ -808,7 +808,7 @@ function build_indiv_map($indifacts, $famids) {
if (!empty($markers[$k]['info']))
echo ': ', addslashes($markers[$k]['info']);
if (!empty($markers[$k]["name"])) {
- $person=Person::getInstance($markers[$k]['name']);
+ $person=WT_Person::getInstance($markers[$k]['name']);
if ($person) {
echo ': <a href=\"', $person->getRawUrl(), '\">', $person->canDisplayName() ? PrintReady(addcslashes($person->getFullName(), '"')) : i18n::translate('Private'), '</a>';
}
@@ -857,7 +857,7 @@ function build_indiv_map($indifacts, $famids) {
if (!empty($marker["info"]))
echo "<span class=\"field\">{$marker["info"]}</span><br />";
if (!empty($marker["name"])) {
- $person=Person::getInstance($marker['name']);
+ $person=WT_Person::getInstance($marker['name']);
if ($person) {
echo '<a href="', $person->getHtmlUrl(), '">', $person->canDisplayName() ? PrintReady($person->getFullName()) : i18n::translate('Private'), '</a>';
}
diff --git a/modules/googlemap/pedigree_map.php b/modules/googlemap/pedigree_map.php
index 5cb8e5704d..53516aee5d 100644
--- a/modules/googlemap/pedigree_map.php
+++ b/modules/googlemap/pedigree_map.php
@@ -39,7 +39,6 @@ if (!defined('WT_WEBTREES')) {
exit;
}
-require WT_ROOT.'includes/controllers/pedigree_ctrl.php';
require WT_ROOT.'modules/googlemap/defaultconfig.php';
global $PEDIGREE_GENERATIONS, $MAX_PEDIGREE_GENERATIONS, $ENABLE_AUTOCOMPLETE, $MULTI_MEDIA, $SHOW_HIGHLIGHT_IMAGES, $WT_IMAGES;
@@ -48,7 +47,7 @@ global $PEDIGREE_GENERATIONS, $MAX_PEDIGREE_GENERATIONS, $ENABLE_AUTOCOMPLETE, $
$hideflags = safe_GET('hideflags');
$hidelines = safe_GET('hidelines');
-$controller = new PedigreeController();
+$controller = new WT_Controller_Pedigree();
$controller->init();
// Default of 5
@@ -199,7 +198,7 @@ $missing = "";
for ($i=0; $i<($controller->treesize); $i++) {
// -- check to see if we have moved to the next generation
if ($i+1 >= pow(2, $curgen)) {$curgen++;}
- $person = Person::getInstance($controller->treeid[$i]);
+ $person = WT_Person::getInstance($controller->treeid[$i]);
if (!empty($person)) {
$pid = $controller->treeid[$i];
$name = $person->getFullName();
@@ -556,7 +555,7 @@ $colored_line = array("1"=>"#FF0000","2"=>"#0000FF","3"=>"#00FF00",
for ($i=0; $i<($controller->treesize); $i++) {
// moved up to grab the sex of the individuals
- $person = Person::getInstance($controller->treeid[$i]);
+ $person = WT_Person::getInstance($controller->treeid[$i]);
if (!empty($person)) {
$pid = $controller->treeid[$i];
$indirec = $person->getGedcomRecord();
diff --git a/modules/individuals/module.php b/modules/individuals/module.php
index 7cf9703c8f..8755286fd1 100644
--- a/modules/individuals/module.php
+++ b/modules/individuals/module.php
@@ -224,7 +224,7 @@ class individuals_WT_Module extends WT_Module implements WT_Module_Sidebar {
$out = '<ul>';
$private_count = 0;
foreach ($rows as $row) {
- $person=Person::getInstance($row);
+ $person=WT_Person::getInstance($row);
if ($person->canDisplayName()) {
$out .= '<li><a href="'.$person->getHtmlUrl().'">'.$person->getSexImage().' '.$person->getListName().' ';
if ($person->canDisplayDetails()) {
diff --git a/modules/lightbox/album.php b/modules/lightbox/album.php
index de9cb25d6c..e78b58201a 100644
--- a/modules/lightbox/album.php
+++ b/modules/lightbox/album.php
@@ -140,7 +140,7 @@ $sort_i=0; // Used in sorting on lightbox_print_media_row.php page
//------------------------------------------------------------------------------
//------------------------------------------------------------------------------
-// Build Relatives navigator from includes/controllers/individual_ctrl
+// Build Relatives navigator from individual controller
//------------------------------------------------------------------------------
/*
echo '<td valign="top" align="center" width="220px">';
diff --git a/modules/lightbox/functions/lightbox_print_media_row.php b/modules/lightbox/functions/lightbox_print_media_row.php
index ebfb3037c7..0a4698b4e4 100644
--- a/modules/lightbox/functions/lightbox_print_media_row.php
+++ b/modules/lightbox/functions/lightbox_print_media_row.php
@@ -129,7 +129,7 @@ function lightbox_print_media_row($rtype, $rowm, $pid) {
if (canDisplayFact($pid, $rowm['m_file'], $rowm['mm_gedrec'])) {
// Get the title of the media
- $media=Media::getInstance($rowm["m_media"]);
+ $media=WT_Media::getInstance($rowm["m_media"]);
$rawTitle = $rowm["m_titl"];
if (empty($rawTitle)) $rawTitle = get_gedcom_value("TITL", 2, $rowm["mm_gedrec"]);
if (empty($rawTitle)) $rawTitle = basename($rowm["m_file"]);
diff --git a/modules/relatives/module.php b/modules/relatives/module.php
index 01066d2a82..3f489fb0b4 100644
--- a/modules/relatives/module.php
+++ b/modules/relatives/module.php
@@ -340,8 +340,8 @@ class relatives_WT_Module extends WT_Module implements WT_Module_Tab {
<td class="facts_value">
<a href="javascript:;" onclick="return addnewchild('<?php echo $family->getXref(); ?>');"><?php echo $child_u; ?></a>
<span style='white-space:nowrap;'>
- <a href="javascript:;" onclick="return addnewchild('<?php echo $family->getXref(); ?>','M');"><?php echo Person::sexImage('M', 'small', '', $child_m); ?></a>
- <a href="javascript:;" onclick="return addnewchild('<?php echo $family->getXref(); ?>','F');"><?php echo Person::sexImage('F', 'small', '', $child_f); ?></a>
+ <a href="javascript:;" onclick="return addnewchild('<?php echo $family->getXref(); ?>','M');"><?php echo WT_Person::sexImage('M', 'small', '', $child_m); ?></a>
+ <a href="javascript:;" onclick="return addnewchild('<?php echo $family->getXref(); ?>','F');"><?php echo WT_Person::sexImage('F', 'small', '', $child_f); ?></a>
</span>
<?php
if ($type=='spouse') {
diff --git a/modules/review_changes/module.php b/modules/review_changes/module.php
index a2484ef506..b5299057fd 100644
--- a/modules/review_changes/module.php
+++ b/modules/review_changes/module.php
@@ -125,7 +125,7 @@ class review_changes_WT_Module extends WT_Module implements WT_Module_Block {
" GROUP BY xref"
)->execute(array(WT_GED_ID))->fetchAll();
foreach ($changes as $change) {
- $record=GedcomRecord::getInstance($change->xref);
+ $record=WT_GedcomRecord::getInstance($change->xref);
if ($record->canDisplayDetails()) {
$content.='<b>'.PrintReady($record->getFullName()).'</b> '.getLRM().'('.$record->getXref().')'.getLRM();
switch ($record->getType()) {
diff --git a/modules/stories/module.php b/modules/stories/module.php
index b782189ebf..874a534190 100644
--- a/modules/stories/module.php
+++ b/modules/stories/module.php
@@ -252,7 +252,7 @@ class stories_WT_Module extends WT_Module implements WT_Module_Block, WT_Module_
echo '<input type="text" name="xref" id="pid" size="4" value="'.$xref.'" />';
print_findindi_link("xref", "pid");
if ($xref) {
- $person=Person::getInstance($xref);
+ $person=WT_Person::getInstance($xref);
if ($person) {
echo ' ', $person->format_list('span');
}
@@ -325,7 +325,7 @@ class stories_WT_Module extends WT_Module implements WT_Module_Block, WT_Module_
echo '</td><td class="list_label center width10">', i18n::translate('Delete'), help_link('delete_story', $this->getName()), '</tr>';
}
foreach ($stories as $story) {
- $indi=Person::getInstance($story->xref);
+ $indi=WT_Person::getInstance($story->xref);
if ($indi) {
$name="<a href=\"".$indi->getHtmlUrl()."#stories\">".$indi->getFullName()."</a>";
} else {
@@ -366,7 +366,7 @@ class stories_WT_Module extends WT_Module implements WT_Module_Block, WT_Module_
echo '</td><td class="list_label">', i18n::translate('Person');
}
foreach ($stories as $story) {
- $indi=Person::getInstance($story->xref);
+ $indi=WT_Person::getInstance($story->xref);
if ($indi) {
$name="<a href=\"".$indi->getHtmlUrl()."#stories\">".$indi->getFullName()."</a>";
} else {
diff --git a/modules/todo/module.php b/modules/todo/module.php
index 81b9faf912..f921ad87a0 100644
--- a/modules/todo/module.php
+++ b/modules/todo/module.php
@@ -74,7 +74,6 @@ class todo_WT_Module extends WT_Module implements WT_Module_Block {
$content='';
require_once WT_ROOT.'js/sorttable.js.htm';
- require_once WT_ROOT.'includes/classes/class_gedcomrecord.php';
$table_id = 'ID'.floor(microtime()*1000000); // sorttable requires a unique ID
$content .= '<table id="'.$table_id.'" class="sortable list_table center">';
@@ -90,7 +89,7 @@ class todo_WT_Module extends WT_Module implements WT_Module_Block {
$found=false;
$end_jd=$show_future ? 99999999 : WT_CLIENT_JD;
foreach (get_calendar_events(0, $end_jd, '_TODO', WT_GED_ID) as $todo) {
- $record=GedcomRecord::getInstance($todo['id']);
+ $record=WT_GedcomRecord::getInstance($todo['id']);
if ($record && $record->canDisplayDetails()) {
$user_name=get_gedcom_value('_WT_USER', 2, $todo['factrec']);
if ($user_name==WT_USER_NAME || !$user_name && $show_unassigned || $user_name && $show_other) {
diff --git a/modules/top10_pageviews/module.php b/modules/top10_pageviews/module.php
index 0d3c480533..fc20634b95 100644
--- a/modules/top10_pageviews/module.php
+++ b/modules/top10_pageviews/module.php
@@ -90,7 +90,7 @@ class top10_pageviews_WT_Module extends WT_Module implements WT_Module_Block {
$content .= "<table>";
}
foreach ($top10 as $id=>$count) {
- $record=GedcomRecord::getInstance($id);
+ $record=WT_GedcomRecord::getInstance($id);
if ($record && $record->canDisplayDetails()) {
$content .= '<tr valign="top">';
if ($count_placement=='before') {
diff --git a/modules/user_favorites/module.php b/modules/user_favorites/module.php
index 859a2c7b6a..8d3bedeaa2 100644
--- a/modules/user_favorites/module.php
+++ b/modules/user_favorites/module.php
@@ -207,7 +207,7 @@ class user_favorites_WT_Module extends WT_Module implements WT_Module_Block {
$content .= ob_get_clean();
$content .= PrintReady($favorite["note"]);
} else {
- $record=GedcomRecord::getInstance($favorite['gid']);
+ $record=WT_GedcomRecord::getInstance($favorite['gid']);
$content .= "<div id=\"box".$favorite["gid"].".0\" class=\"person_box\">";
if ($ctype=="user" || WT_USER_IS_ADMIN) $content .= $removeFavourite;
if ($record) {
diff --git a/modules/yahrzeit/module.php b/modules/yahrzeit/module.php
index 93d3dc0a90..f6958ab19f 100644
--- a/modules/yahrzeit/module.php
+++ b/modules/yahrzeit/module.php
@@ -126,7 +126,6 @@ class yahrzeit_WT_Module extends WT_Module implements WT_Module_Block {
case 'table':
default:
require_once WT_ROOT.'js/sorttable.js.htm';
- require_once WT_ROOT.'includes/classes/class_gedcomrecord.php';
$table_id = "ID".floor(microtime()*1000000); // sorttable requires a unique ID
$content .= "<table id=\"{$table_id}\" class=\"sortable list_table center\">";
$content .= "<tr>";
diff --git a/modules/clippings/clippings_ctrl.php b/modules/clippings/clippings_ctrl.php
index f05bde87f5..8cec16d434 100644
--- a/modules/clippings/clippings_ctrl.php
+++ b/modules/clippings/clippings_ctrl.php
@@ -34,9 +34,7 @@ if (!defined('WT_WEBTREES')) {
define('WT_CLIPPINGS_CTRL', '');
-require_once WT_ROOT.'includes/classes/class_person.php';
require_once WT_ROOT.'includes/functions/functions.php';
-require_once WT_ROOT.'includes/controllers/basecontrol.php';
require_once WT_ROOT.'library/pclzip.lib.php';
function same_group($a, $b) {
@@ -68,7 +66,7 @@ function id_in_cart($id) {
/**
* Main controller class for the Clippings page.
*/
-class ClippingsController extends BaseController {
+class WT_Controller_Clippings extends WT_Controller_Base {
var $download_data;
var $media_list = array();
@@ -88,10 +86,10 @@ class ClippingsController extends BaseController {
/**
* @param string $thing the id of the person
*/
- function ClippingsControllerRoot() {
- parent :: BaseController();
+ function __construct() {
+ parent::__construct();
}
//----------------beginning of function definitions for ClippingsControllerRoot
function init() {
global $SCRIPT_NAME, $MEDIA_DIRECTORY, $MEDIA_FIREWALL_ROOTDIR, $GEDCOM, $cart;
@@ -122,7 +120,7 @@ class ClippingsController extends BaseController {
if ($this->action == 'add') {
if (empty($this->type) && !empty($this->id)) {
$this->type="";
- $obj = GedcomRecord::getInstance($this->id);
+ $obj = WT_GedcomRecord::getInstance($this->id);
if (is_null($obj)) {
$this->id="";
$this->action="";
@@ -180,7 +178,7 @@ class ClippingsController extends BaseController {
} else
if ($this->type == 'indi') {
if ($others == 'parents') {
- foreach (Person::getInstance($this->id)->getChildFamilies() as $family) {
+ foreach (WT_Person::getInstance($this->id)->getChildFamilies() as $family) {
$clipping = array ();
$clipping['type'] = "fam";
$clipping['id'] = $family->getXref();
@@ -196,7 +194,7 @@ class ClippingsController extends BaseController {
$this->add_ancestors_to_cart_families($this->id, $this->level2);
} else
if ($others == 'members') {
- foreach (Person::getInstance($this->id)->getSpouseFamilies() as $family) {
+ foreach (WT_Person::getInstance($this->id)->getSpouseFamilies() as $family) {
$clipping = array ();
$clipping['type'] = "fam";
$clipping['id'] = $family->getXref();
@@ -206,7 +204,7 @@ class ClippingsController extends BaseController {
}
} else
if ($others == 'descendants') {
- foreach (Person::getInstance($this->id)->getSpouseFamilies() as $family) {
+ foreach (WT_Person::getInstance($this->id)->getSpouseFamilies() as $family) {
$clipping = array ();
$clipping['type'] = "fam";
$clipping['id'] = $family->getXref();
@@ -517,7 +515,7 @@ class ClippingsController extends BaseController {
}
$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch, PREG_SET_ORDER);
for ($i = 0; $i < $num; $i++) {
- $cfamids = Person::getInstance($smatch[$i][1])->getSpouseFamilyIds();
+ $cfamids = WT_Person::getInstance($smatch[$i][1])->getSpouseFamilyIds();
if (count($cfamids) > 0) {
foreach ($cfamids as $indexval => $cfamid) {
if (!id_in_cart($cfamid)) {
@@ -571,7 +569,7 @@ class ClippingsController extends BaseController {
//-- recursively adds direct-line ancestors to cart
function add_ancestors_to_cart($pid, $level="") {
global $cart;
- $famids = Person::getInstance($pid)->getChildFamilyIds();
+ $famids = WT_Person::getInstance($pid)->getChildFamilyIds();
if (count($famids) > 0) {
foreach ($famids as $indexval => $famid) {
if ($level=="" || $level > 0) {
@@ -605,7 +603,7 @@ class ClippingsController extends BaseController {
//-- recursively adds direct-line ancestors and their families to the cart
function add_ancestors_to_cart_families($pid, $level="") {
global $cart;
- $famids = Person::getInstance($pid)->getChildFamilyIds();
+ $famids = WT_Person::getInstance($pid)->getChildFamilyIds();
if (count($famids) > 0) {
foreach ($famids as $indexval => $famid) {
if ($level=="" || $level > 0) {
@@ -88,10 +86,10 @@ class ClippingsController extends BaseController {
}
- //----------------beginning of function definitions for ClippingsControllerRoot
+ //----------------beginning of function definitions for WT_Controller_Clippings
function init() {
global $SCRIPT_NAME, $MEDIA_DIRECTORY, $MEDIA_FIREWALL_ROOTDIR, $GEDCOM, $cart;